@@ -283,3 +283,23 @@ class Client(object):
 
     def GetCampaignParams(self, CampaignID):
         return self.call_method("GetCampaignParams", {"CampaignID": CampaignID})
+
+    def GetImages(self, logins=None):
+        query = {}
+        if logins:
+            query["Logins"] = logins
+
+        return self.call_method("AdImage", {
+            "Action": "Get",
+            "SelectionCriteria": query,
+        })["AdImages"]
+
+    def GetImageAssociations(self, logins=None):
+        query = {}
+        if logins:
+            query["Logins"] = logins
+
+        return self.call_method("AdImageAssociation", {
+            "Action": "Get",
+            "SelectionCriteria": query,
+        })["AdImageAssociations"]
